#!/usr/bin/env python3
"""
CLI to open PEPs in your browser
"""
from __future__ import annotations

import webbrowser

try:
    # Python 3.8+
    import importlib.metadata as importlib_metadata
except ImportError:
    # Python 3.7 and lower
    import importlib_metadata  # type: ignore

__version__ = importlib_metadata.version(__name__)

VERSION_TO_PEP = {
    "1.6": 160,
    "2.0": 200,
    "2.1": 226,
    "2.2": 251,
    "2.3": 283,
    "2.4": 320,
    "2.5": 356,
    "2.6": 361,
    "2.7": 373,
    "3.0": 361,
    "3.1": 375,
    "3.2": 392,
    "3.3": 398,
    "3.4": 429,
    "3.5": 478,
    "3.6": 494,
    "3.7": 537,
    "3.8": 569,
    "3.9": 596,
    "3.10": 619,
    "3.11": 664,
}


def url(search: str, base_url: str | None = None, pr: int | None = None) -> str:
    """Get PEP URL"""
    try:
        number = int(search)
    except ValueError:
        number = VERSION_TO_PEP[search]

    if pr:
        base_url = f"https://pep-previews--{pr}.org.readthedocs.build"

    return base_url.rstrip("/") + f"/pep-{number:04}" + "/"


def pep(search: str, base_url: str | None = None, pr: int | None = None) -> None:
    """Open this PEP in the browser"""
    pep_url = url(search, base_url, pr)
    print(pep_url)
    webbrowser.open(pep_url, new=2)  # 2 = open in a new tab, if possible



#!/usr/bin/env python3
"""
CLI to open PEPs in your browser
"""
import argparse

import pepotron


class Formatter(
    argparse.ArgumentDefaultsHelpFormatter,
    argparse.RawDescriptionHelpFormatter,
):
    pass


def main() -> None:
    parser = argparse.ArgumentParser(description=__doc__, formatter_class=Formatter)
    parser.add_argument("search", help="PEP number, or Python version for its schedule")
    parser.add_argument(
        "-u", "--url", default="https://peps.python.org", help="Base URL for PEPs"
    )
    parser.add_argument("--pr", type=int, help="Open preview for python/peps PR")
    parser.add_argument(
        "-V", "--version", action="version", version=f"%(prog)s {pepotron.__version__}"
    )
    args = parser.parse_args()
    pepotron.pep(search=args.search, base_url=args.url, pr=args.pr)


if __name__ == "__main__":
    main()



"""
Unit tests
"""
import pytest

import pepotron


@pytest.mark.parametrize(
    "search, base_url, expected_url",
    [
        (
            "8",
            "https://peps.python.org",
            "https://peps.python.org/pep-0008/",
        ),
        (
            "12",
            "https://peps.python.org/",
            "https://peps.python.org/pep-0012/",
        ),
        (
            "2.7",
            "https://peps.python.org/",
            "https://peps.python.org/pep-0373/",
        ),
        (
            "3.11",
            "https://hugovk.github.io/peps",
            "https://hugovk.github.io/peps/pep-0664/",
        ),
    ],
)
def test_url(search: str, base_url: str, expected_url: str) -> None:
    # Act
    pep_url = pepotron.url(search, base_url)
    # Assert
    assert pep_url == expected_url


def test_url_pr() -> None:
    # Arrange
    search = "594"
    pr = 2440
    # Act
    pep_url = pepotron.url(search, pr=pr)
    # Assert
    assert pep_url == "https://pep-previews--2440.org.readthedocs.build/pep-0594/"
